# coding: utf-8

"""
    printnanny-api-client

    Official API client library for printnanny.ai  # noqa: E501

    The version of the OpenAPI document: 0.110.0
    Contact: leigh@printnanny.ai
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from printnanny_api_client.configuration import Configuration


class PiSoftwareUpdatePayload(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'wic_tarball_url': 'str',
        'wic_bmap_url': 'str',
        'manifest_url': 'str',
        'swu_url': 'str',
        'version_id': 'str',
        'version': 'str',
        'version_codename': 'str'
    }

    attribute_map = {
        'wic_tarball_url': 'wic_tarball_url',
        'wic_bmap_url': 'wic_bmap_url',
        'manifest_url': 'manifest_url',
        'swu_url': 'swu_url',
        'version_id': 'version_id',
        'version': 'version',
        'version_codename': 'version_codename'
    }

    def __init__(self, wic_tarball_url=None, wic_bmap_url=None, manifest_url=None, swu_url=None, version_id=None, version=None, version_codename=None, local_vars_configuration=None):  # noqa: E501
        """PiSoftwareUpdatePayload - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._wic_tarball_url = None
        self._wic_bmap_url = None
        self._manifest_url = None
        self._swu_url = None
        self._version_id = None
        self._version = None
        self._version_codename = None
        self.discriminator = None

        self.wic_tarball_url = wic_tarball_url
        self.wic_bmap_url = wic_bmap_url
        self.manifest_url = manifest_url
        self.swu_url = swu_url
        self.version_id = version_id
        self.version = version
        self.version_codename = version_codename

    @property
    def wic_tarball_url(self):
        """Gets the wic_tarball_url of this PiSoftwareUpdatePayload.  # noqa: E501


        :return: The wic_tarball_url of this PiSoftwareUpdatePayload.  # noqa: E501
        :rtype: str
        """
        return self._wic_tarball_url

    @wic_tarball_url.setter
    def wic_tarball_url(self, wic_tarball_url):
        """Sets the wic_tarball_url of this PiSoftwareUpdatePayload.


        :param wic_tarball_url: The wic_tarball_url of this PiSoftwareUpdatePayload.  # noqa: E501
        :type wic_tarball_url: str
        """
        if self.local_vars_configuration.client_side_validation and wic_tarball_url is None:  # noqa: E501
            raise ValueError("Invalid value for `wic_tarball_url`, must not be `None`")  # noqa: E501

        self._wic_tarball_url = wic_tarball_url

    @property
    def wic_bmap_url(self):
        """Gets the wic_bmap_url of this PiSoftwareUpdatePayload.  # noqa: E501


        :return: The wic_bmap_url of this PiSoftwareUpdatePayload.  # noqa: E501
        :rtype: str
        """
        return self._wic_bmap_url

    @wic_bmap_url.setter
    def wic_bmap_url(self, wic_bmap_url):
        """Sets the wic_bmap_url of this PiSoftwareUpdatePayload.


        :param wic_bmap_url: The wic_bmap_url of this PiSoftwareUpdatePayload.  # noqa: E501
        :type wic_bmap_url: str
        """
        if self.local_vars_configuration.client_side_validation and wic_bmap_url is None:  # noqa: E501
            raise ValueError("Invalid value for `wic_bmap_url`, must not be `None`")  # noqa: E501

        self._wic_bmap_url = wic_bmap_url

    @property
    def manifest_url(self):
        """Gets the manifest_url of this PiSoftwareUpdatePayload.  # noqa: E501


        :return: The manifest_url of this PiSoftwareUpdatePayload.  # noqa: E501
        :rtype: str
        """
        return self._manifest_url

    @manifest_url.setter
    def manifest_url(self, manifest_url):
        """Sets the manifest_url of this PiSoftwareUpdatePayload.


        :param manifest_url: The manifest_url of this PiSoftwareUpdatePayload.  # noqa: E501
        :type manifest_url: str
        """
        if self.local_vars_configuration.client_side_validation and manifest_url is None:  # noqa: E501
            raise ValueError("Invalid value for `manifest_url`, must not be `None`")  # noqa: E501

        self._manifest_url = manifest_url

    @property
    def swu_url(self):
        """Gets the swu_url of this PiSoftwareUpdatePayload.  # noqa: E501


        :return: The swu_url of this PiSoftwareUpdatePayload.  # noqa: E501
        :rtype: str
        """
        return self._swu_url

    @swu_url.setter
    def swu_url(self, swu_url):
        """Sets the swu_url of this PiSoftwareUpdatePayload.


        :param swu_url: The swu_url of this PiSoftwareUpdatePayload.  # noqa: E501
        :type swu_url: str
        """
        if self.local_vars_configuration.client_side_validation and swu_url is None:  # noqa: E501
            raise ValueError("Invalid value for `swu_url`, must not be `None`")  # noqa: E501

        self._swu_url = swu_url

    @property
    def version_id(self):
        """Gets the version_id of this PiSoftwareUpdatePayload.  # noqa: E501


        :return: The version_id of this PiSoftwareUpdatePayload.  # noqa: E501
        :rtype: str
        """
        return self._version_id

    @version_id.setter
    def version_id(self, version_id):
        """Sets the version_id of this PiSoftwareUpdatePayload.


        :param version_id: The version_id of this PiSoftwareUpdatePayload.  # noqa: E501
        :type version_id: str
        """
        if self.local_vars_configuration.client_side_validation and version_id is None:  # noqa: E501
            raise ValueError("Invalid value for `version_id`, must not be `None`")  # noqa: E501

        self._version_id = version_id

    @property
    def version(self):
        """Gets the version of this PiSoftwareUpdatePayload.  # noqa: E501


        :return: The version of this PiSoftwareUpdatePayload.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this PiSoftwareUpdatePayload.


        :param version: The version of this PiSoftwareUpdatePayload.  # noqa: E501
        :type version: str
        """
        if self.local_vars_configuration.client_side_validation and version is None:  # noqa: E501
            raise ValueError("Invalid value for `version`, must not be `None`")  # noqa: E501

        self._version = version

    @property
    def version_codename(self):
        """Gets the version_codename of this PiSoftwareUpdatePayload.  # noqa: E501


        :return: The version_codename of this PiSoftwareUpdatePayload.  # noqa: E501
        :rtype: str
        """
        return self._version_codename

    @version_codename.setter
    def version_codename(self, version_codename):
        """Sets the version_codename of this PiSoftwareUpdatePayload.


        :param version_codename: The version_codename of this PiSoftwareUpdatePayload.  # noqa: E501
        :type version_codename: str
        """
        if self.local_vars_configuration.client_side_validation and version_codename is None:  # noqa: E501
            raise ValueError("Invalid value for `version_codename`, must not be `None`")  # noqa: E501

        self._version_codename = version_codename

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PiSoftwareUpdatePayload):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PiSoftwareUpdatePayload):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for printnanny.ai  # noqa: E501

    The version of the OpenAPI document: 0.110.0
    Contact: leigh@printnanny.ai
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from printnanny_api_client.configuration import Configuration


class OctoPrintServer(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'settings': 'OctoPrintSettings',
        'base_path': 'str',
        'venv_path': 'str',
        'pip_path': 'str',
        'python_path': 'str',
        'octoprint_version': 'str',
        'pip_version': 'str',
        'python_version': 'str',
        'printnanny_plugin_version': 'str',
        'created_dt': 'datetime',
        'updated_dt': 'datetime',
        'user': 'int',
        'pi': 'int'
    }

    attribute_map = {
        'id': 'id',
        'settings': 'settings',
        'base_path': 'base_path',
        'venv_path': 'venv_path',
        'pip_path': 'pip_path',
        'python_path': 'python_path',
        'octoprint_version': 'octoprint_version',
        'pip_version': 'pip_version',
        'python_version': 'python_version',
        'printnanny_plugin_version': 'printnanny_plugin_version',
        'created_dt': 'created_dt',
        'updated_dt': 'updated_dt',
        'user': 'user',
        'pi': 'pi'
    }

    def __init__(self, id=None, settings=None, base_path=None, venv_path=None, pip_path=None, python_path=None, octoprint_version=None, pip_version=None, python_version=None, printnanny_plugin_version=None, created_dt=None, updated_dt=None, user=None, pi=None, local_vars_configuration=None):  # noqa: E501
        """OctoPrintServer - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._settings = None
        self._base_path = None
        self._venv_path = None
        self._pip_path = None
        self._python_path = None
        self._octoprint_version = None
        self._pip_version = None
        self._python_version = None
        self._printnanny_plugin_version = None
        self._created_dt = None
        self._updated_dt = None
        self._user = None
        self._pi = None
        self.discriminator = None

        self.id = id
        self.settings = settings
        self.base_path = base_path
        self.venv_path = venv_path
        self.pip_path = pip_path
        self.python_path = python_path
        if octoprint_version is not None:
            self.octoprint_version = octoprint_version
        if pip_version is not None:
            self.pip_version = pip_version
        if python_version is not None:
            self.python_version = python_version
        if printnanny_plugin_version is not None:
            self.printnanny_plugin_version = printnanny_plugin_version
        self.created_dt = created_dt
        self.updated_dt = updated_dt
        self.user = user
        self.pi = pi

    @property
    def id(self):
        """Gets the id of this OctoPrintServer.  # noqa: E501


        :return: The id of this OctoPrintServer.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this OctoPrintServer.


        :param id: The id of this OctoPrintServer.  # noqa: E501
        :type id: int
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def settings(self):
        """Gets the settings of this OctoPrintServer.  # noqa: E501


        :return: The settings of this OctoPrintServer.  # noqa: E501
        :rtype: OctoPrintSettings
        """
        return self._settings

    @settings.setter
    def settings(self, settings):
        """Sets the settings of this OctoPrintServer.


        :param settings: The settings of this OctoPrintServer.  # noqa: E501
        :type settings: OctoPrintSettings
        """

        self._settings = settings

    @property
    def base_path(self):
        """Gets the base_path of this OctoPrintServer.  # noqa: E501


        :return: The base_path of this OctoPrintServer.  # noqa: E501
        :rtype: str
        """
        return self._base_path

    @base_path.setter
    def base_path(self, base_path):
        """Sets the base_path of this OctoPrintServer.


        :param base_path: The base_path of this OctoPrintServer.  # noqa: E501
        :type base_path: str
        """
        if self.local_vars_configuration.client_side_validation and base_path is None:  # noqa: E501
            raise ValueError("Invalid value for `base_path`, must not be `None`")  # noqa: E501

        self._base_path = base_path

    @property
    def venv_path(self):
        """Gets the venv_path of this OctoPrintServer.  # noqa: E501


        :return: The venv_path of this OctoPrintServer.  # noqa: E501
        :rtype: str
        """
        return self._venv_path

    @venv_path.setter
    def venv_path(self, venv_path):
        """Sets the venv_path of this OctoPrintServer.


        :param venv_path: The venv_path of this OctoPrintServer.  # noqa: E501
        :type venv_path: str
        """
        if self.local_vars_configuration.client_side_validation and venv_path is None:  # noqa: E501
            raise ValueError("Invalid value for `venv_path`, must not be `None`")  # noqa: E501

        self._venv_path = venv_path

    @property
    def pip_path(self):
        """Gets the pip_path of this OctoPrintServer.  # noqa: E501


        :return: The pip_path of this OctoPrintServer.  # noqa: E501
        :rtype: str
        """
        return self._pip_path

    @pip_path.setter
    def pip_path(self, pip_path):
        """Sets the pip_path of this OctoPrintServer.


        :param pip_path: The pip_path of this OctoPrintServer.  # noqa: E501
        :type pip_path: str
        """
        if self.local_vars_configuration.client_side_validation and pip_path is None:  # noqa: E501
            raise ValueError("Invalid value for `pip_path`, must not be `None`")  # noqa: E501

        self._pip_path = pip_path

    @property
    def python_path(self):
        """Gets the python_path of this OctoPrintServer.  # noqa: E501


        :return: The python_path of this OctoPrintServer.  # noqa: E501
        :rtype: str
        """
        return self._python_path

    @python_path.setter
    def python_path(self, python_path):
        """Sets the python_path of this OctoPrintServer.


        :param python_path: The python_path of this OctoPrintServer.  # noqa: E501
        :type python_path: str
        """
        if self.local_vars_configuration.client_side_validation and python_path is None:  # noqa: E501
            raise ValueError("Invalid value for `python_path`, must not be `None`")  # noqa: E501

        self._python_path = python_path

    @property
    def octoprint_version(self):
        """Gets the octoprint_version of this OctoPrintServer.  # noqa: E501


        :return: The octoprint_version of this OctoPrintServer.  # noqa: E501
        :rtype: str
        """
        return self._octoprint_version

    @octoprint_version.setter
    def octoprint_version(self, octoprint_version):
        """Sets the octoprint_version of this OctoPrintServer.


        :param octoprint_version: The octoprint_version of this OctoPrintServer.  # noqa: E501
        :type octoprint_version: str
        """
        if (self.local_vars_configuration.client_side_validation and
                octoprint_version is not None and len(octoprint_version) > 32):
            raise ValueError("Invalid value for `octoprint_version`, length must be less than or equal to `32`")  # noqa: E501

        self._octoprint_version = octoprint_version

    @property
    def pip_version(self):
        """Gets the pip_version of this OctoPrintServer.  # noqa: E501


        :return: The pip_version of this OctoPrintServer.  # noqa: E501
        :rtype: str
        """
        return self._pip_version

    @pip_version.setter
    def pip_version(self, pip_version):
        """Sets the pip_version of this OctoPrintServer.


        :param pip_version: The pip_version of this OctoPrintServer.  # noqa: E501
        :type pip_version: str
        """
        if (self.local_vars_configuration.client_side_validation and
                pip_version is not None and len(pip_version) > 32):
            raise ValueError("Invalid value for `pip_version`, length must be less than or equal to `32`")  # noqa: E501

        self._pip_version = pip_version

    @property
    def python_version(self):
        """Gets the python_version of this OctoPrintServer.  # noqa: E501


        :return: The python_version of this OctoPrintServer.  # noqa: E501
        :rtype: str
        """
        return self._python_version

    @python_version.setter
    def python_version(self, python_version):
        """Sets the python_version of this OctoPrintServer.


        :param python_version: The python_version of this OctoPrintServer.  # noqa: E501
        :type python_version: str
        """
        if (self.local_vars_configuration.client_side_validation and
                python_version is not None and len(python_version) > 32):
            raise ValueError("Invalid value for `python_version`, length must be less than or equal to `32`")  # noqa: E501

        self._python_version = python_version

    @property
    def printnanny_plugin_version(self):
        """Gets the printnanny_plugin_version of this OctoPrintServer.  # noqa: E501


        :return: The printnanny_plugin_version of this OctoPrintServer.  # noqa: E501
        :rtype: str
        """
        return self._printnanny_plugin_version

    @printnanny_plugin_version.setter
    def printnanny_plugin_version(self, printnanny_plugin_version):
        """Sets the printnanny_plugin_version of this OctoPrintServer.


        :param printnanny_plugin_version: The printnanny_plugin_version of this OctoPrintServer.  # noqa: E501
        :type printnanny_plugin_version: str
        """
        if (self.local_vars_configuration.client_side_validation and
                printnanny_plugin_version is not None and len(printnanny_plugin_version) > 64):
            raise ValueError("Invalid value for `printnanny_plugin_version`, length must be less than or equal to `64`")  # noqa: E501

        self._printnanny_plugin_version = printnanny_plugin_version

    @property
    def created_dt(self):
        """Gets the created_dt of this OctoPrintServer.  # noqa: E501


        :return: The created_dt of this OctoPrintServer.  # noqa: E501
        :rtype: datetime
        """
        return self._created_dt

    @created_dt.setter
    def created_dt(self, created_dt):
        """Sets the created_dt of this OctoPrintServer.


        :param created_dt: The created_dt of this OctoPrintServer.  # noqa: E501
        :type created_dt: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_dt is None:  # noqa: E501
            raise ValueError("Invalid value for `created_dt`, must not be `None`")  # noqa: E501

        self._created_dt = created_dt

    @property
    def updated_dt(self):
        """Gets the updated_dt of this OctoPrintServer.  # noqa: E501


        :return: The updated_dt of this OctoPrintServer.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_dt

    @updated_dt.setter
    def updated_dt(self, updated_dt):
        """Sets the updated_dt of this OctoPrintServer.


        :param updated_dt: The updated_dt of this OctoPrintServer.  # noqa: E501
        :type updated_dt: datetime
        """
        if self.local_vars_configuration.client_side_validation and updated_dt is None:  # noqa: E501
            raise ValueError("Invalid value for `updated_dt`, must not be `None`")  # noqa: E501

        self._updated_dt = updated_dt

    @property
    def user(self):
        """Gets the user of this OctoPrintServer.  # noqa: E501


        :return: The user of this OctoPrintServer.  # noqa: E501
        :rtype: int
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this OctoPrintServer.


        :param user: The user of this OctoPrintServer.  # noqa: E501
        :type user: int
        """
        if self.local_vars_configuration.client_side_validation and user is None:  # noqa: E501
            raise ValueError("Invalid value for `user`, must not be `None`")  # noqa: E501

        self._user = user

    @property
    def pi(self):
        """Gets the pi of this OctoPrintServer.  # noqa: E501


        :return: The pi of this OctoPrintServer.  # noqa: E501
        :rtype: int
        """
        return self._pi

    @pi.setter
    def pi(self, pi):
        """Sets the pi of this OctoPrintServer.


        :param pi: The pi of this OctoPrintServer.  # noqa: E501
        :type pi: int
        """
        if self.local_vars_configuration.client_side_validation and pi is None:  # noqa: E501
            raise ValueError("Invalid value for `pi`, must not be `None`")  # noqa: E501

        self._pi = pi

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OctoPrintServer):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OctoPrintServer):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for printnanny.ai  # noqa: E501

    The version of the OpenAPI document: 0.110.0
    Contact: leigh@printnanny.ai
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from printnanny_api_client.configuration import Configuration


class PiNatsAppRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'app_name': 'str',
        'json': 'dict(str, object)',
        'pi': 'int',
        'organization': 'NatsOrganizationRequest',
        'organization_user': 'int'
    }

    attribute_map = {
        'app_name': 'app_name',
        'json': 'json',
        'pi': 'pi',
        'organization': 'organization',
        'organization_user': 'organization_user'
    }

    def __init__(self, app_name=None, json=None, pi=None, organization=None, organization_user=None, local_vars_configuration=None):  # noqa: E501
        """PiNatsAppRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._app_name = None
        self._json = None
        self._pi = None
        self._organization = None
        self._organization_user = None
        self.discriminator = None

        if app_name is not None:
            self.app_name = app_name
        if json is not None:
            self.json = json
        self.pi = pi
        self.organization = organization
        self.organization_user = organization_user

    @property
    def app_name(self):
        """Gets the app_name of this PiNatsAppRequest.  # noqa: E501


        :return: The app_name of this PiNatsAppRequest.  # noqa: E501
        :rtype: str
        """
        return self._app_name

    @app_name.setter
    def app_name(self, app_name):
        """Sets the app_name of this PiNatsAppRequest.


        :param app_name: The app_name of this PiNatsAppRequest.  # noqa: E501
        :type app_name: str
        """
        if (self.local_vars_configuration.client_side_validation and
                app_name is not None and len(app_name) > 255):
            raise ValueError("Invalid value for `app_name`, length must be less than or equal to `255`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                app_name is not None and len(app_name) < 1):
            raise ValueError("Invalid value for `app_name`, length must be greater than or equal to `1`")  # noqa: E501

        self._app_name = app_name

    @property
    def json(self):
        """Gets the json of this PiNatsAppRequest.  # noqa: E501

        Output of `nsc describe account`  # noqa: E501

        :return: The json of this PiNatsAppRequest.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._json

    @json.setter
    def json(self, json):
        """Sets the json of this PiNatsAppRequest.

        Output of `nsc describe account`  # noqa: E501

        :param json: The json of this PiNatsAppRequest.  # noqa: E501
        :type json: dict(str, object)
        """

        self._json = json

    @property
    def pi(self):
        """Gets the pi of this PiNatsAppRequest.  # noqa: E501


        :return: The pi of this PiNatsAppRequest.  # noqa: E501
        :rtype: int
        """
        return self._pi

    @pi.setter
    def pi(self, pi):
        """Sets the pi of this PiNatsAppRequest.


        :param pi: The pi of this PiNatsAppRequest.  # noqa: E501
        :type pi: int
        """
        if self.local_vars_configuration.client_side_validation and pi is None:  # noqa: E501
            raise ValueError("Invalid value for `pi`, must not be `None`")  # noqa: E501

        self._pi = pi

    @property
    def organization(self):
        """Gets the organization of this PiNatsAppRequest.  # noqa: E501


        :return: The organization of this PiNatsAppRequest.  # noqa: E501
        :rtype: NatsOrganizationRequest
        """
        return self._organization

    @organization.setter
    def organization(self, organization):
        """Sets the organization of this PiNatsAppRequest.


        :param organization: The organization of this PiNatsAppRequest.  # noqa: E501
        :type organization: NatsOrganizationRequest
        """
        if self.local_vars_configuration.client_side_validation and organization is None:  # noqa: E501
            raise ValueError("Invalid value for `organization`, must not be `None`")  # noqa: E501

        self._organization = organization

    @property
    def organization_user(self):
        """Gets the organization_user of this PiNatsAppRequest.  # noqa: E501


        :return: The organization_user of this PiNatsAppRequest.  # noqa: E501
        :rtype: int
        """
        return self._organization_user

    @organization_user.setter
    def organization_user(self, organization_user):
        """Sets the organization_user of this PiNatsAppRequest.


        :param organization_user: The organization_user of this PiNatsAppRequest.  # noqa: E501
        :type organization_user: int
        """
        if self.local_vars_configuration.client_side_validation and organization_user is None:  # noqa: E501
            raise ValueError("Invalid value for `organization_user`, must not be `None`")  # noqa: E501

        self._organization_user = organization_user

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PiNatsAppRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PiNatsAppRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for printnanny.ai  # noqa: E501

    The version of the OpenAPI document: 0.110.0
    Contact: leigh@printnanny.ai
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from printnanny_api_client.configuration import Configuration


class NatsOrganization(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'name': 'str',
        'is_active': 'bool',
        'created': 'datetime',
        'modified': 'datetime',
        'slug': 'str',
        'json': 'dict(str, object)',
        'imports': 'list[int]',
        'exports': 'list[int]',
        'users': 'list[int]'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'is_active': 'is_active',
        'created': 'created',
        'modified': 'modified',
        'slug': 'slug',
        'json': 'json',
        'imports': 'imports',
        'exports': 'exports',
        'users': 'users'
    }

    def __init__(self, id=None, name=None, is_active=None, created=None, modified=None, slug=None, json=None, imports=None, exports=None, users=None, local_vars_configuration=None):  # noqa: E501
        """NatsOrganization - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._name = None
        self._is_active = None
        self._created = None
        self._modified = None
        self._slug = None
        self._json = None
        self._imports = None
        self._exports = None
        self._users = None
        self.discriminator = None

        self.id = id
        self.name = name
        if is_active is not None:
            self.is_active = is_active
        self.created = created
        self.modified = modified
        self.slug = slug
        if json is not None:
            self.json = json
        self.imports = imports
        self.exports = exports
        self.users = users

    @property
    def id(self):
        """Gets the id of this NatsOrganization.  # noqa: E501


        :return: The id of this NatsOrganization.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this NatsOrganization.


        :param id: The id of this NatsOrganization.  # noqa: E501
        :type id: int
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def name(self):
        """Gets the name of this NatsOrganization.  # noqa: E501

        The name of the organization  # noqa: E501

        :return: The name of this NatsOrganization.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this NatsOrganization.

        The name of the organization  # noqa: E501

        :param name: The name of this NatsOrganization.  # noqa: E501
        :type name: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) > 200):
            raise ValueError("Invalid value for `name`, length must be less than or equal to `200`")  # noqa: E501

        self._name = name

    @property
    def is_active(self):
        """Gets the is_active of this NatsOrganization.  # noqa: E501


        :return: The is_active of this NatsOrganization.  # noqa: E501
        :rtype: bool
        """
        return self._is_active

    @is_active.setter
    def is_active(self, is_active):
        """Sets the is_active of this NatsOrganization.


        :param is_active: The is_active of this NatsOrganization.  # noqa: E501
        :type is_active: bool
        """

        self._is_active = is_active

    @property
    def created(self):
        """Gets the created of this NatsOrganization.  # noqa: E501


        :return: The created of this NatsOrganization.  # noqa: E501
        :rtype: datetime
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this NatsOrganization.


        :param created: The created of this NatsOrganization.  # noqa: E501
        :type created: datetime
        """
        if self.local_vars_configuration.client_side_validation and created is None:  # noqa: E501
            raise ValueError("Invalid value for `created`, must not be `None`")  # noqa: E501

        self._created = created

    @property
    def modified(self):
        """Gets the modified of this NatsOrganization.  # noqa: E501


        :return: The modified of this NatsOrganization.  # noqa: E501
        :rtype: datetime
        """
        return self._modified

    @modified.setter
    def modified(self, modified):
        """Sets the modified of this NatsOrganization.


        :param modified: The modified of this NatsOrganization.  # noqa: E501
        :type modified: datetime
        """
        if self.local_vars_configuration.client_side_validation and modified is None:  # noqa: E501
            raise ValueError("Invalid value for `modified`, must not be `None`")  # noqa: E501

        self._modified = modified

    @property
    def slug(self):
        """Gets the slug of this NatsOrganization.  # noqa: E501

        The name in all lowercase, suitable for URL identification  # noqa: E501

        :return: The slug of this NatsOrganization.  # noqa: E501
        :rtype: str
        """
        return self._slug

    @slug.setter
    def slug(self, slug):
        """Sets the slug of this NatsOrganization.

        The name in all lowercase, suitable for URL identification  # noqa: E501

        :param slug: The slug of this NatsOrganization.  # noqa: E501
        :type slug: str
        """
        if self.local_vars_configuration.client_side_validation and slug is None:  # noqa: E501
            raise ValueError("Invalid value for `slug`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                slug is not None and len(slug) > 200):
            raise ValueError("Invalid value for `slug`, length must be less than or equal to `200`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                slug is not None and not re.search(r'^[-a-zA-Z0-9_]+$', slug)):  # noqa: E501
            raise ValueError(r"Invalid value for `slug`, must be a follow pattern or equal to `/^[-a-zA-Z0-9_]+$/`")  # noqa: E501

        self._slug = slug

    @property
    def json(self):
        """Gets the json of this NatsOrganization.  # noqa: E501

        Output of `nsc describe account`  # noqa: E501

        :return: The json of this NatsOrganization.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._json

    @json.setter
    def json(self, json):
        """Sets the json of this NatsOrganization.

        Output of `nsc describe account`  # noqa: E501

        :param json: The json of this NatsOrganization.  # noqa: E501
        :type json: dict(str, object)
        """

        self._json = json

    @property
    def imports(self):
        """Gets the imports of this NatsOrganization.  # noqa: E501


        :return: The imports of this NatsOrganization.  # noqa: E501
        :rtype: list[int]
        """
        return self._imports

    @imports.setter
    def imports(self, imports):
        """Sets the imports of this NatsOrganization.


        :param imports: The imports of this NatsOrganization.  # noqa: E501
        :type imports: list[int]
        """
        if self.local_vars_configuration.client_side_validation and imports is None:  # noqa: E501
            raise ValueError("Invalid value for `imports`, must not be `None`")  # noqa: E501

        self._imports = imports

    @property
    def exports(self):
        """Gets the exports of this NatsOrganization.  # noqa: E501


        :return: The exports of this NatsOrganization.  # noqa: E501
        :rtype: list[int]
        """
        return self._exports

    @exports.setter
    def exports(self, exports):
        """Sets the exports of this NatsOrganization.


        :param exports: The exports of this NatsOrganization.  # noqa: E501
        :type exports: list[int]
        """
        if self.local_vars_configuration.client_side_validation and exports is None:  # noqa: E501
            raise ValueError("Invalid value for `exports`, must not be `None`")  # noqa: E501

        self._exports = exports

    @property
    def users(self):
        """Gets the users of this NatsOrganization.  # noqa: E501


        :return: The users of this NatsOrganization.  # noqa: E501
        :rtype: list[int]
        """
        return self._users

    @users.setter
    def users(self, users):
        """Sets the users of this NatsOrganization.


        :param users: The users of this NatsOrganization.  # noqa: E501
        :type users: list[int]
        """
        if self.local_vars_configuration.client_side_validation and users is None:  # noqa: E501
            raise ValueError("Invalid value for `users`, must not be `None`")  # noqa: E501

        self._users = users

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NatsOrganization):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, NatsOrganization):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for printnanny.ai  # noqa: E501

    The version of the OpenAPI document: 0.110.0
    Contact: leigh@printnanny.ai
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import printnanny_api_client
from printnanny_api_client.models.product import Product  # noqa: E501
from printnanny_api_client.rest import ApiException

class TestProduct(unittest.TestCase):
    """Product unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Product
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = printnanny_api_client.models.product.Product()  # noqa: E501
        if include_optional :
            return Product(
                id = '', 
                djstripe_product = printnanny_api_client.models.dj_stripe_product.DjStripeProduct(
                    djstripe_id = 56, 
                    djstripe_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    djstripe_updated = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    id = '', 
                    livemode = True, 
                    created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    metadata = {
                        'key' : null
                        }, 
                    description = '', 
                    name = '', 
                    type = null, 
                    active = True, 
                    attributes = {
                        'key' : null
                        }, 
                    caption = '', 
                    deactivate_on = {
                        'key' : null
                        }, 
                    images = {
                        'key' : null
                        }, 
                    package_dimensions = {
                        'key' : null
                        }, 
                    shippable = True, 
                    url = '', 
                    statement_descriptor = '', 
                    unit_label = '', 
                    djstripe_owner_account = '', ), 
                prices = [
                    printnanny_api_client.models.dj_stripe_price.DjStripePrice(
                        djstripe_id = 56, 
                        billing_scheme = 'per_unit', 
                        human_readable_price = '', 
                        tiers_mode = 'graduated', 
                        djstripe_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        djstripe_updated = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        id = '', 
                        livemode = True, 
                        created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        metadata = {
                            'key' : null
                            }, 
                        description = '', 
                        active = True, 
                        currency = '', 
                        nickname = '', 
                        recurring = {
                            'key' : null
                            }, 
                        type = null, 
                        unit_amount = -9223372036854775808, 
                        unit_amount_decimal = '-8072888', 
                        lookup_key = '', 
                        tiers = {
                            'key' : null
                            }, 
                        transform_quantity = {
                            'key' : null
                            }, 
                        djstripe_owner_account = '', 
                        product = '', )
                    ], 
                deleted = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                created_dt = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                updated_dt = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                sku = '', 
                slug = '', 
                unit_label = '', 
                name = '', 
                description = '', 
                statement_descriptor = '', 
                images = [
                    ''
                    ], 
                is_active = True, 
                is_shippable = True, 
                is_preorder = True, 
                is_subscription = True, 
                stripe_price_lookup_key = '', 
                stripe_product_id = ''
            )
        else :
            return Product(
                djstripe_product = printnanny_api_client.models.dj_stripe_product.DjStripeProduct(
                    djstripe_id = 56, 
                    djstripe_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    djstripe_updated = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    id = '', 
                    livemode = True, 
                    created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    metadata = {
                        'key' : null
                        }, 
                    description = '', 
                    name = '', 
                    type = null, 
                    active = True, 
                    attributes = {
                        'key' : null
                        }, 
                    caption = '', 
                    deactivate_on = {
                        'key' : null
                        }, 
                    images = {
                        'key' : null
                        }, 
                    package_dimensions = {
                        'key' : null
                        }, 
                    shippable = True, 
                    url = '', 
                    statement_descriptor = '', 
                    unit_label = '', 
                    djstripe_owner_account = '', ),
                prices = [
                    printnanny_api_client.models.dj_stripe_price.DjStripePrice(
                        djstripe_id = 56, 
                        billing_scheme = 'per_unit', 
                        human_readable_price = '', 
                        tiers_mode = 'graduated', 
                        djstripe_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        djstripe_updated = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        id = '', 
                        livemode = True, 
                        created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        metadata = {
                            'key' : null
                            }, 
                        description = '', 
                        active = True, 
                        currency = '', 
                        nickname = '', 
                        recurring = {
                            'key' : null
                            }, 
                        type = null, 
                        unit_amount = -9223372036854775808, 
                        unit_amount_decimal = '-8072888', 
                        lookup_key = '', 
                        tiers = {
                            'key' : null
                            }, 
                        transform_quantity = {
                            'key' : null
                            }, 
                        djstripe_owner_account = '', 
                        product = '', )
                    ],
                deleted = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                created_dt = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_dt = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                sku = '',
                slug = '',
                unit_label = '',
                name = '',
                description = '',
                statement_descriptor = '',
                is_shippable = True,
                is_preorder = True,
                is_subscription = True,
        )

    def testProduct(self):
        """Test Product"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for printnanny.ai  # noqa: E501

    The version of the OpenAPI document: 0.110.0
    Contact: leigh@printnanny.ai
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from printnanny_api_client.configuration import Configuration


class PatchedEmailAlertSettingsRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'progress_percent': 'int',
        'enabled': 'bool',
        'event_types': 'list[EventTypesEnum]'
    }

    attribute_map = {
        'progress_percent': 'progress_percent',
        'enabled': 'enabled',
        'event_types': 'event_types'
    }

    def __init__(self, progress_percent=None, enabled=None, event_types=None, local_vars_configuration=None):  # noqa: E501
        """PatchedEmailAlertSettingsRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._progress_percent = None
        self._enabled = None
        self._event_types = None
        self.discriminator = None

        if progress_percent is not None:
            self.progress_percent = progress_percent
        if enabled is not None:
            self.enabled = enabled
        if event_types is not None:
            self.event_types = event_types

    @property
    def progress_percent(self):
        """Gets the progress_percent of this PatchedEmailAlertSettingsRequest.  # noqa: E501


        :return: The progress_percent of this PatchedEmailAlertSettingsRequest.  # noqa: E501
        :rtype: int
        """
        return self._progress_percent

    @progress_percent.setter
    def progress_percent(self, progress_percent):
        """Sets the progress_percent of this PatchedEmailAlertSettingsRequest.


        :param progress_percent: The progress_percent of this PatchedEmailAlertSettingsRequest.  # noqa: E501
        :type progress_percent: int
        """
        if (self.local_vars_configuration.client_side_validation and
                progress_percent is not None and progress_percent > 2147483647):  # noqa: E501
            raise ValueError("Invalid value for `progress_percent`, must be a value less than or equal to `2147483647`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                progress_percent is not None and progress_percent < -2147483648):  # noqa: E501
            raise ValueError("Invalid value for `progress_percent`, must be a value greater than or equal to `-2147483648`")  # noqa: E501

        self._progress_percent = progress_percent

    @property
    def enabled(self):
        """Gets the enabled of this PatchedEmailAlertSettingsRequest.  # noqa: E501


        :return: The enabled of this PatchedEmailAlertSettingsRequest.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this PatchedEmailAlertSettingsRequest.


        :param enabled: The enabled of this PatchedEmailAlertSettingsRequest.  # noqa: E501
        :type enabled: bool
        """

        self._enabled = enabled

    @property
    def event_types(self):
        """Gets the event_types of this PatchedEmailAlertSettingsRequest.  # noqa: E501


        :return: The event_types of this PatchedEmailAlertSettingsRequest.  # noqa: E501
        :rtype: list[EventTypesEnum]
        """
        return self._event_types

    @event_types.setter
    def event_types(self, event_types):
        """Sets the event_types of this PatchedEmailAlertSettingsRequest.


        :param event_types: The event_types of this PatchedEmailAlertSettingsRequest.  # noqa: E501
        :type event_types: list[EventTypesEnum]
        """

        self._event_types = event_types

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PatchedEmailAlertSettingsRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PatchedEmailAlertSettingsRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for printnanny.ai  # noqa: E501

    The version of the OpenAPI document: 0.110.0
    Contact: leigh@printnanny.ai
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from printnanny_api_client.configuration import Configuration


class DjStripeCheckoutSession(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'djstripe_id': 'int',
        'billing_address_collection': 'StripeSessionBillingAddressCollection',
        'mode': 'StripeSessionMode',
        'submit_type': 'StripeSubmitTypeStatus',
        'djstripe_created': 'datetime',
        'djstripe_updated': 'datetime',
        'id': 'str',
        'livemode': 'bool',
        'created': 'datetime',
        'metadata': 'dict(str, object)',
        'description': 'str',
        'cancel_url': 'str',
        'client_reference_id': 'str',
        'customer_email': 'str',
        'display_items': 'dict(str, object)',
        'locale': 'str',
        'payment_method_types': 'dict(str, object)',
        'success_url': 'str',
        'djstripe_owner_account': 'str',
        'customer': 'str',
        'payment_intent': 'str',
        'subscription': 'str'
    }

    attribute_map = {
        'djstripe_id': 'djstripe_id',
        'billing_address_collection': 'billing_address_collection',
        'mode': 'mode',
        'submit_type': 'submit_type',
        'djstripe_created': 'djstripe_created',
        'djstripe_updated': 'djstripe_updated',
        'id': 'id',
        'livemode': 'livemode',
        'created': 'created',
        'metadata': 'metadata',
        'description': 'description',
        'cancel_url': 'cancel_url',
        'client_reference_id': 'client_reference_id',
        'customer_email': 'customer_email',
        'display_items': 'display_items',
        'locale': 'locale',
        'payment_method_types': 'payment_method_types',
        'success_url': 'success_url',
        'djstripe_owner_account': 'djstripe_owner_account',
        'customer': 'customer',
        'payment_intent': 'payment_intent',
        'subscription': 'subscription'
    }

    def __init__(self, djstripe_id=None, billing_address_collection=None, mode=None, submit_type=None, djstripe_created=None, djstripe_updated=None, id=None, livemode=None, created=None, metadata=None, description=None, cancel_url=None, client_reference_id=None, customer_email=None, display_items=None, locale=None, payment_method_types=None, success_url=None, djstripe_owner_account=None, customer=None, payment_intent=None, subscription=None, local_vars_configuration=None):  # noqa: E501
        """DjStripeCheckoutSession - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._djstripe_id = None
        self._billing_address_collection = None
        self._mode = None
        self._submit_type = None
        self._djstripe_created = None
        self._djstripe_updated = None
        self._id = None
        self._livemode = None
        self._created = None
        self._metadata = None
        self._description = None
        self._cancel_url = None
        self._client_reference_id = None
        self._customer_email = None
        self._display_items = None
        self._locale = None
        self._payment_method_types = None
        self._success_url = None
        self._djstripe_owner_account = None
        self._customer = None
        self._payment_intent = None
        self._subscription = None
        self.discriminator = None

        self.djstripe_id = djstripe_id
        self.billing_address_collection = billing_address_collection
        self.mode = mode
        self.submit_type = submit_type
        self.djstripe_created = djstripe_created
        self.djstripe_updated = djstripe_updated
        self.id = id
        self.livemode = livemode
        self.created = created
        self.metadata = metadata
        self.description = description
        if cancel_url is not None:
            self.cancel_url = cancel_url
        if client_reference_id is not None:
            self.client_reference_id = client_reference_id
        if customer_email is not None:
            self.customer_email = customer_email
        self.display_items = display_items
        if locale is not None:
            self.locale = locale
        self.payment_method_types = payment_method_types
        if success_url is not None:
            self.success_url = success_url
        self.djstripe_owner_account = djstripe_owner_account
        self.customer = customer
        self.payment_intent = payment_intent
        self.subscription = subscription

    @property
    def djstripe_id(self):
        """Gets the djstripe_id of this DjStripeCheckoutSession.  # noqa: E501


        :return: The djstripe_id of this DjStripeCheckoutSession.  # noqa: E501
        :rtype: int
        """
        return self._djstripe_id

    @djstripe_id.setter
    def djstripe_id(self, djstripe_id):
        """Sets the djstripe_id of this DjStripeCheckoutSession.


        :param djstripe_id: The djstripe_id of this DjStripeCheckoutSession.  # noqa: E501
        :type djstripe_id: int
        """
        if self.local_vars_configuration.client_side_validation and djstripe_id is None:  # noqa: E501
            raise ValueError("Invalid value for `djstripe_id`, must not be `None`")  # noqa: E501

        self._djstripe_id = djstripe_id

    @property
    def billing_address_collection(self):
        """Gets the billing_address_collection of this DjStripeCheckoutSession.  # noqa: E501


        :return: The billing_address_collection of this DjStripeCheckoutSession.  # noqa: E501
        :rtype: StripeSessionBillingAddressCollection
        """
        return self._billing_address_collection

    @billing_address_collection.setter
    def billing_address_collection(self, billing_address_collection):
        """Sets the billing_address_collection of this DjStripeCheckoutSession.


        :param billing_address_collection: The billing_address_collection of this DjStripeCheckoutSession.  # noqa: E501
        :type billing_address_collection: StripeSessionBillingAddressCollection
        """
        if self.local_vars_configuration.client_side_validation and billing_address_collection is None:  # noqa: E501
            raise ValueError("Invalid value for `billing_address_collection`, must not be `None`")  # noqa: E501

        self._billing_address_collection = billing_address_collection

    @property
    def mode(self):
        """Gets the mode of this DjStripeCheckoutSession.  # noqa: E501


        :return: The mode of this DjStripeCheckoutSession.  # noqa: E501
        :rtype: StripeSessionMode
        """
        return self._mode

    @mode.setter
    def mode(self, mode):
        """Sets the mode of this DjStripeCheckoutSession.


        :param mode: The mode of this DjStripeCheckoutSession.  # noqa: E501
        :type mode: StripeSessionMode
        """
        if self.local_vars_configuration.client_side_validation and mode is None:  # noqa: E501
            raise ValueError("Invalid value for `mode`, must not be `None`")  # noqa: E501

        self._mode = mode

    @property
    def submit_type(self):
        """Gets the submit_type of this DjStripeCheckoutSession.  # noqa: E501


        :return: The submit_type of this DjStripeCheckoutSession.  # noqa: E501
        :rtype: StripeSubmitTypeStatus
        """
        return self._submit_type

    @submit_type.setter
    def submit_type(self, submit_type):
        """Sets the submit_type of this DjStripeCheckoutSession.


        :param submit_type: The submit_type of this DjStripeCheckoutSession.  # noqa: E501
        :type submit_type: StripeSubmitTypeStatus
        """
        if self.local_vars_configuration.client_side_validation and submit_type is None:  # noqa: E501
            raise ValueError("Invalid value for `submit_type`, must not be `None`")  # noqa: E501

        self._submit_type = submit_type

    @property
    def djstripe_created(self):
        """Gets the djstripe_created of this DjStripeCheckoutSession.  # noqa: E501


        :return: The djstripe_created of this DjStripeCheckoutSession.  # noqa: E501
        :rtype: datetime
        """
        return self._djstripe_created

    @djstripe_created.setter
    def djstripe_created(self, djstripe_created):
        """Sets the djstripe_created of this DjStripeCheckoutSession.


        :param djstripe_created: The djstripe_created of this DjStripeCheckoutSession.  # noqa: E501
        :type djstripe_created: datetime
        """
        if self.local_vars_configuration.client_side_validation and djstripe_created is None:  # noqa: E501
            raise ValueError("Invalid value for `djstripe_created`, must not be `None`")  # noqa: E501

        self._djstripe_created = djstripe_created

    @property
    def djstripe_updated(self):
        """Gets the djstripe_updated of this DjStripeCheckoutSession.  # noqa: E501


        :return: The djstripe_updated of this DjStripeCheckoutSession.  # noqa: E501
        :rtype: datetime
        """
        return self._djstripe_updated

    @djstripe_updated.setter
    def djstripe_updated(self, djstripe_updated):
        """Sets the djstripe_updated of this DjStripeCheckoutSession.


        :param djstripe_updated: The djstripe_updated of this DjStripeCheckoutSession.  # noqa: E501
        :type djstripe_updated: datetime
        """
        if self.local_vars_configuration.client_side_validation and djstripe_updated is None:  # noqa: E501
            raise ValueError("Invalid value for `djstripe_updated`, must not be `None`")  # noqa: E501

        self._djstripe_updated = djstripe_updated

    @property
    def id(self):
        """Gets the id of this DjStripeCheckoutSession.  # noqa: E501


        :return: The id of this DjStripeCheckoutSession.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DjStripeCheckoutSession.


        :param id: The id of this DjStripeCheckoutSession.  # noqa: E501
        :type id: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                id is not None and len(id) > 255):
            raise ValueError("Invalid value for `id`, length must be less than or equal to `255`")  # noqa: E501

        self._id = id

    @property
    def livemode(self):
        """Gets the livemode of this DjStripeCheckoutSession.  # noqa: E501

        Null here indicates that the livemode status is unknown or was previously unrecorded. Otherwise, this field indicates whether this record comes from Stripe test mode or live mode operation.  # noqa: E501

        :return: The livemode of this DjStripeCheckoutSession.  # noqa: E501
        :rtype: bool
        """
        return self._livemode

    @livemode.setter
    def livemode(self, livemode):
        """Sets the livemode of this DjStripeCheckoutSession.

        Null here indicates that the livemode status is unknown or was previously unrecorded. Otherwise, this field indicates whether this record comes from Stripe test mode or live mode operation.  # noqa: E501

        :param livemode: The livemode of this DjStripeCheckoutSession.  # noqa: E501
        :type livemode: bool
        """

        self._livemode = livemode

    @property
    def created(self):
        """Gets the created of this DjStripeCheckoutSession.  # noqa: E501

        The datetime this object was created in stripe.  # noqa: E501

        :return: The created of this DjStripeCheckoutSession.  # noqa: E501
        :rtype: datetime
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this DjStripeCheckoutSession.

        The datetime this object was created in stripe.  # noqa: E501

        :param created: The created of this DjStripeCheckoutSession.  # noqa: E501
        :type created: datetime
        """

        self._created = created

    @property
    def metadata(self):
        """Gets the metadata of this DjStripeCheckoutSession.  # noqa: E501

        A set of key/value pairs that you can attach to an object. It can be useful for storing additional information about an object in a structured format.  # noqa: E501

        :return: The metadata of this DjStripeCheckoutSession.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this DjStripeCheckoutSession.

        A set of key/value pairs that you can attach to an object. It can be useful for storing additional information about an object in a structured format.  # noqa: E501

        :param metadata: The metadata of this DjStripeCheckoutSession.  # noqa: E501
        :type metadata: dict(str, object)
        """

        self._metadata = metadata

    @property
    def description(self):
        """Gets the description of this DjStripeCheckoutSession.  # noqa: E501

        A description of this object.  # noqa: E501

        :return: The description of this DjStripeCheckoutSession.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this DjStripeCheckoutSession.

        A description of this object.  # noqa: E501

        :param description: The description of this DjStripeCheckoutSession.  # noqa: E501
        :type description: str
        """

        self._description = description

    @property
    def cancel_url(self):
        """Gets the cancel_url of this DjStripeCheckoutSession.  # noqa: E501

        The URL the customer will be directed to if theydecide to cancel payment and return to your website.  # noqa: E501

        :return: The cancel_url of this DjStripeCheckoutSession.  # noqa: E501
        :rtype: str
        """
        return self._cancel_url

    @cancel_url.setter
    def cancel_url(self, cancel_url):
        """Sets the cancel_url of this DjStripeCheckoutSession.

        The URL the customer will be directed to if theydecide to cancel payment and return to your website.  # noqa: E501

        :param cancel_url: The cancel_url of this DjStripeCheckoutSession.  # noqa: E501
        :type cancel_url: str
        """
        if (self.local_vars_configuration.client_side_validation and
                cancel_url is not None and len(cancel_url) > 5000):
            raise ValueError("Invalid value for `cancel_url`, length must be less than or equal to `5000`")  # noqa: E501

        self._cancel_url = cancel_url

    @property
    def client_reference_id(self):
        """Gets the client_reference_id of this DjStripeCheckoutSession.  # noqa: E501

        A unique string to reference the Checkout Session.This can be a customer ID, a cart ID, or similar, andcan be used to reconcile the session with your internal systems.  # noqa: E501

        :return: The client_reference_id of this DjStripeCheckoutSession.  # noqa: E501
        :rtype: str
        """
        return self._client_reference_id

    @client_reference_id.setter
    def client_reference_id(self, client_reference_id):
        """Sets the client_reference_id of this DjStripeCheckoutSession.

        A unique string to reference the Checkout Session.This can be a customer ID, a cart ID, or similar, andcan be used to reconcile the session with your internal systems.  # noqa: E501

        :param client_reference_id: The client_reference_id of this DjStripeCheckoutSession.  # noqa: E501
        :type client_reference_id: str
        """
        if (self.local_vars_configuration.client_side_validation and
                client_reference_id is not None and len(client_reference_id) > 5000):
            raise ValueError("Invalid value for `client_reference_id`, length must be less than or equal to `5000`")  # noqa: E501

        self._client_reference_id = client_reference_id

    @property
    def customer_email(self):
        """Gets the customer_email of this DjStripeCheckoutSession.  # noqa: E501

        If provided, this value will be used when the Customer object is created.  # noqa: E501

        :return: The customer_email of this DjStripeCheckoutSession.  # noqa: E501
        :rtype: str
        """
        return self._customer_email

    @customer_email.setter
    def customer_email(self, customer_email):
        """Sets the customer_email of this DjStripeCheckoutSession.

        If provided, this value will be used when the Customer object is created.  # noqa: E501

        :param customer_email: The customer_email of this DjStripeCheckoutSession.  # noqa: E501
        :type customer_email: str
        """
        if (self.local_vars_configuration.client_side_validation and
                customer_email is not None and len(customer_email) > 255):
            raise ValueError("Invalid value for `customer_email`, length must be less than or equal to `255`")  # noqa: E501

        self._customer_email = customer_email

    @property
    def display_items(self):
        """Gets the display_items of this DjStripeCheckoutSession.  # noqa: E501

        The line items, plans, or SKUs purchased by the customer.  # noqa: E501

        :return: The display_items of this DjStripeCheckoutSession.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._display_items

    @display_items.setter
    def display_items(self, display_items):
        """Sets the display_items of this DjStripeCheckoutSession.

        The line items, plans, or SKUs purchased by the customer.  # noqa: E501

        :param display_items: The display_items of this DjStripeCheckoutSession.  # noqa: E501
        :type display_items: dict(str, object)
        """

        self._display_items = display_items

    @property
    def locale(self):
        """Gets the locale of this DjStripeCheckoutSession.  # noqa: E501

        The IETF language tag of the locale Checkout is displayed in.If blank or auto, the browser's locale is used.  # noqa: E501

        :return: The locale of this DjStripeCheckoutSession.  # noqa: E501
        :rtype: str
        """
        return self._locale

    @locale.setter
    def locale(self, locale):
        """Sets the locale of this DjStripeCheckoutSession.

        The IETF language tag of the locale Checkout is displayed in.If blank or auto, the browser's locale is used.  # noqa: E501

        :param locale: The locale of this DjStripeCheckoutSession.  # noqa: E501
        :type locale: str
        """
        if (self.local_vars_configuration.client_side_validation and
                locale is not None and len(locale) > 255):
            raise ValueError("Invalid value for `locale`, length must be less than or equal to `255`")  # noqa: E501

        self._locale = locale

    @property
    def payment_method_types(self):
        """Gets the payment_method_types of this DjStripeCheckoutSession.  # noqa: E501

        The list of payment method types (e.g. card) that this Checkout Session is allowed to accept.  # noqa: E501

        :return: The payment_method_types of this DjStripeCheckoutSession.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._payment_method_types

    @payment_method_types.setter
    def payment_method_types(self, payment_method_types):
        """Sets the payment_method_types of this DjStripeCheckoutSession.

        The list of payment method types (e.g. card) that this Checkout Session is allowed to accept.  # noqa: E501

        :param payment_method_types: The payment_method_types of this DjStripeCheckoutSession.  # noqa: E501
        :type payment_method_types: dict(str, object)
        """
        if self.local_vars_configuration.client_side_validation and payment_method_types is None:  # noqa: E501
            raise ValueError("Invalid value for `payment_method_types`, must not be `None`")  # noqa: E501

        self._payment_method_types = payment_method_types

    @property
    def success_url(self):
        """Gets the success_url of this DjStripeCheckoutSession.  # noqa: E501

        The URL the customer will be directed to after the payment or subscriptioncreation is successful.  # noqa: E501

        :return: The success_url of this DjStripeCheckoutSession.  # noqa: E501
        :rtype: str
        """
        return self._success_url

    @success_url.setter
    def success_url(self, success_url):
        """Sets the success_url of this DjStripeCheckoutSession.

        The URL the customer will be directed to after the payment or subscriptioncreation is successful.  # noqa: E501

        :param success_url: The success_url of this DjStripeCheckoutSession.  # noqa: E501
        :type success_url: str
        """
        if (self.local_vars_configuration.client_side_validation and
                success_url is not None and len(success_url) > 5000):
            raise ValueError("Invalid value for `success_url`, length must be less than or equal to `5000`")  # noqa: E501

        self._success_url = success_url

    @property
    def djstripe_owner_account(self):
        """Gets the djstripe_owner_account of this DjStripeCheckoutSession.  # noqa: E501

        The Stripe Account this object belongs to.  # noqa: E501

        :return: The djstripe_owner_account of this DjStripeCheckoutSession.  # noqa: E501
        :rtype: str
        """
        return self._djstripe_owner_account

    @djstripe_owner_account.setter
    def djstripe_owner_account(self, djstripe_owner_account):
        """Sets the djstripe_owner_account of this DjStripeCheckoutSession.

        The Stripe Account this object belongs to.  # noqa: E501

        :param djstripe_owner_account: The djstripe_owner_account of this DjStripeCheckoutSession.  # noqa: E501
        :type djstripe_owner_account: str
        """

        self._djstripe_owner_account = djstripe_owner_account

    @property
    def customer(self):
        """Gets the customer of this DjStripeCheckoutSession.  # noqa: E501

        Customer this Checkout is for if one exists.  # noqa: E501

        :return: The customer of this DjStripeCheckoutSession.  # noqa: E501
        :rtype: str
        """
        return self._customer

    @customer.setter
    def customer(self, customer):
        """Sets the customer of this DjStripeCheckoutSession.

        Customer this Checkout is for if one exists.  # noqa: E501

        :param customer: The customer of this DjStripeCheckoutSession.  # noqa: E501
        :type customer: str
        """

        self._customer = customer

    @property
    def payment_intent(self):
        """Gets the payment_intent of this DjStripeCheckoutSession.  # noqa: E501

        PaymentIntent created if SKUs or line items were provided.  # noqa: E501

        :return: The payment_intent of this DjStripeCheckoutSession.  # noqa: E501
        :rtype: str
        """
        return self._payment_intent

    @payment_intent.setter
    def payment_intent(self, payment_intent):
        """Sets the payment_intent of this DjStripeCheckoutSession.

        PaymentIntent created if SKUs or line items were provided.  # noqa: E501

        :param payment_intent: The payment_intent of this DjStripeCheckoutSession.  # noqa: E501
        :type payment_intent: str
        """

        self._payment_intent = payment_intent

    @property
    def subscription(self):
        """Gets the subscription of this DjStripeCheckoutSession.  # noqa: E501

        Subscription created if one or more plans were provided.  # noqa: E501

        :return: The subscription of this DjStripeCheckoutSession.  # noqa: E501
        :rtype: str
        """
        return self._subscription

    @subscription.setter
    def subscription(self, subscription):
        """Sets the subscription of this DjStripeCheckoutSession.

        Subscription created if one or more plans were provided.  # noqa: E501

        :param subscription: The subscription of this DjStripeCheckoutSession.  # noqa: E501
        :type subscription: str
        """

        self._subscription = subscription

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DjStripeCheckoutSession):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DjStripeCheckoutSession):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for printnanny.ai  # noqa: E501

    The version of the OpenAPI document: 0.110.0
    Contact: leigh@printnanny.ai
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import printnanny_api_client
from printnanny_api_client.models.dj_stripe_customer import DjStripeCustomer  # noqa: E501
from printnanny_api_client.rest import ApiException

class TestDjStripeCustomer(unittest.TestCase):
    """DjStripeCustomer unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test DjStripeCustomer
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = printnanny_api_client.models.dj_stripe_customer.DjStripeCustomer()  # noqa: E501
        if include_optional :
            return DjStripeCustomer(
                djstripe_id = 56, 
                djstripe_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                djstripe_updated = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                id = '', 
                livemode = True, 
                created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                metadata = {
                    'key' : null
                    }, 
                description = '', 
                address = {
                    'key' : null
                    }, 
                balance = -9223372036854775808, 
                currency = '', 
                delinquent = True, 
                deleted = True, 
                coupon_start = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                coupon_end = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                email = '', 
                invoice_prefix = '', 
                invoice_settings = {
                    'key' : null
                    }, 
                name = '', 
                phone = '', 
                preferred_locales = {
                    'key' : null
                    }, 
                shipping = {
                    'key' : null
                    }, 
                tax_exempt = None, 
                date_purged = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                djstripe_owner_account = '', 
                default_source = '', 
                coupon = 56, 
                default_payment_method = '', 
                subscriber = 56
            )
        else :
            return DjStripeCustomer(
                djstripe_id = 56,
                djstripe_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                djstripe_updated = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                id = '',
                coupon_start = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                coupon_end = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                date_purged = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                djstripe_owner_account = '',
                subscriber = 56,
        )

    def testDjStripeCustomer(self):
        """Test DjStripeCustomer"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for printnanny.ai  # noqa: E501

    The version of the OpenAPI document: 0.110.0
    Contact: leigh@printnanny.ai
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import printnanny_api_client
from printnanny_api_client.models.dj_stripe_payment_intent import DjStripePaymentIntent  # noqa: E501
from printnanny_api_client.rest import ApiException

class TestDjStripePaymentIntent(unittest.TestCase):
    """DjStripePaymentIntent unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test DjStripePaymentIntent
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = printnanny_api_client.models.dj_stripe_payment_intent.DjStripePaymentIntent()  # noqa: E501
        if include_optional :
            return DjStripePaymentIntent(
                djstripe_id = 56, 
                cancellation_reason = 'abandoned', 
                charges = [
                    printnanny_api_client.models.dj_stripe_charge.DjStripeCharge(
                        djstripe_id = 56, 
                        failure_code = 'account_already_exists', 
                        djstripe_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        djstripe_updated = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        id = '', 
                        livemode = True, 
                        created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        metadata = {
                            'key' : null
                            }, 
                        description = '', 
                        amount = '-8072', 
                        amount_captured = '-8072', 
                        amount_refunded = '-8072', 
                        application = '', 
                        application_fee_amount = '-8072', 
                        billing_details = {
                            'key' : null
                            }, 
                        calculated_statement_descriptor = '', 
                        captured = True, 
                        currency = '', 
                        disputed = True, 
                        failure_message = '', 
                        fraud_details = {
                            'key' : null
                            }, 
                        outcome = {
                            'key' : null
                            }, 
                        paid = True, 
                        payment_method_details = {
                            'key' : null
                            }, 
                        receipt_email = '', 
                        receipt_number = '', 
                        receipt_url = '', 
                        refunded = True, 
                        shipping = {
                            'key' : null
                            }, 
                        statement_descriptor = '', 
                        statement_descriptor_suffix = '', 
                        status = null, 
                        transfer_data = {
                            'key' : null
                            }, 
                        transfer_group = '', 
                        djstripe_owner_account = '', 
                        application_fee = '', 
                        balance_transaction = '', 
                        customer = '', 
                        dispute = '', 
                        invoice = '', 
                        on_behalf_of = '', 
                        payment_intent = '', 
                        payment_method = '', 
                        source = '', 
                        source_transfer = '', 
                        transfer = '', )
                    ], 
                setup_future_usage = 'off_session', 
                djstripe_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                djstripe_updated = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                id = '', 
                livemode = True, 
                created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                metadata = {
                    'key' : null
                    }, 
                amount = -9223372036854775808, 
                amount_capturable = -9223372036854775808, 
                amount_received = -9223372036854775808, 
                canceled_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                capture_method = None, 
                client_secret = '', 
                confirmation_method = None, 
                currency = '', 
                description = '', 
                last_payment_error = {
                    'key' : null
                    }, 
                next_action = {
                    'key' : null
                    }, 
                payment_method_types = {
                    'key' : null
                    }, 
                receipt_email = '', 
                shipping = {
                    'key' : null
                    }, 
                statement_descriptor = '', 
                status = None, 
                transfer_data = {
                    'key' : null
                    }, 
                transfer_group = '', 
                djstripe_owner_account = '', 
                customer = '', 
                on_behalf_of = '', 
                payment_method = ''
            )
        else :
            return DjStripePaymentIntent(
                djstripe_id = 56,
                cancellation_reason = 'abandoned',
                charges = [
                    printnanny_api_client.models.dj_stripe_charge.DjStripeCharge(
                        djstripe_id = 56, 
                        failure_code = 'account_already_exists', 
                        djstripe_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        djstripe_updated = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        id = '', 
                        livemode = True, 
                        created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        metadata = {
                            'key' : null
                            }, 
                        description = '', 
                        amount = '-8072', 
                        amount_captured = '-8072', 
                        amount_refunded = '-8072', 
                        application = '', 
                        application_fee_amount = '-8072', 
                        billing_details = {
                            'key' : null
                            }, 
                        calculated_statement_descriptor = '', 
                        captured = True, 
                        currency = '', 
                        disputed = True, 
                        failure_message = '', 
                        fraud_details = {
                            'key' : null
                            }, 
                        outcome = {
                            'key' : null
                            }, 
                        paid = True, 
                        payment_method_details = {
                            'key' : null
                            }, 
                        receipt_email = '', 
                        receipt_number = '', 
                        receipt_url = '', 
                        refunded = True, 
                        shipping = {
                            'key' : null
                            }, 
                        statement_descriptor = '', 
                        statement_descriptor_suffix = '', 
                        status = null, 
                        transfer_data = {
                            'key' : null
                            }, 
                        transfer_group = '', 
                        djstripe_owner_account = '', 
                        application_fee = '', 
                        balance_transaction = '', 
                        customer = '', 
                        dispute = '', 
                        invoice = '', 
                        on_behalf_of = '', 
                        payment_intent = '', 
                        payment_method = '', 
                        source = '', 
                        source_transfer = '', 
                        transfer = '', )
                    ],
                setup_future_usage = 'off_session',
                djstripe_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                djstripe_updated = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                id = '',
                amount = -9223372036854775808,
                amount_capturable = -9223372036854775808,
                amount_received = -9223372036854775808,
                capture_method = None,
                client_secret = '',
                confirmation_method = None,
                currency = '',
                payment_method_types = {
                    'key' : null
                    },
                status = None,
        )

    def testDjStripePaymentIntent(self):
        """Test DjStripePaymentIntent"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for printnanny.ai  # noqa: E501

    The version of the OpenAPI document: 0.110.0
    Contact: leigh@printnanny.ai
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import printnanny_api_client
from printnanny_api_client.api.settings_api import SettingsApi  # noqa: E501
from printnanny_api_client.rest import ApiException


class TestSettingsApi(unittest.TestCase):
    """SettingsApi unit test stubs"""

    def setUp(self):
        self.api = printnanny_api_client.api.settings_api.SettingsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_alert_settings_email_create(self):
        """Test case for alert_settings_email_create

        """
        pass

    def test_alert_settings_email_list(self):
        """Test case for alert_settings_email_list

        """
        pass

    def test_alert_settings_email_partial_update(self):
        """Test case for alert_settings_email_partial_update

        """
        pass

    def test_alert_settings_email_retrieve(self):
        """Test case for alert_settings_email_retrieve

        """
        pass

    def test_alert_settings_email_update(self):
        """Test case for alert_settings_email_update

        """
        pass


if __name__ == '__main__':
    unittest.main()
